/*   This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; version 2 of the License.
   
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
     
     (C) 2006 schan
*/
#ifndef BITMAPFONT_H
#define BITMAPFONT_H

#include <string>
#include <map>
#include <SDL/SDL.h>
#include "font.h"

class BitmapFont// : public Font
{
	public:
	
		BitmapFont();
		~BitmapFont();
		
		void load(const std::string &filename, const std::wstring &chars);

		int draw_text(const char *text, SDL_Surface *dest, int x, int y, bool centerH=false, bool centerV=false);
		int draw_char(char character, SDL_Surface *dest, int x, int y);

		int draw_unicode(const Uint16 *text, SDL_Surface *dest, int x, int y, bool centerH=false, bool centerV=false);
		int draw_unicode(Uint16 unicode_char, SDL_Surface *dest, int x, int y);

		int draw_utf8(const char *text, SDL_Surface *dest, int x, int y, bool centerH=false, bool centerV=false);

		int get_width(const char *text);
		int get_width_utf8(const char *text);
		int get_width_unicode(const Uint16 *unicode_char);
		int get_width_unicode(Uint16 unicode_char);
		int get_height();
		
		SDL_Color get_bg_color();
	
		inline bool loaded() { return bitmap!=NULL; }

		void close();
		
	private:
		SDL_Surface *bitmap;
		std::map<wchar_t,SDL_Rect> clip_rect;
		SDL_Color bg_color;
				
		
		SDL_Color get_pixel(SDL_Surface *screen, int x, int y)
		{
			SDL_Color color;
			Uint32 col;
			
			char *buffer=(char *) screen->pixels;
			
			buffer+=screen->pitch*y;
			buffer+=screen->format->BytesPerPixel*x;
			memcpy(&col, buffer, screen->format->BytesPerPixel);
			SDL_GetRGB(col, screen->format, &color.r, &color.g, &color.b);
			
			return color;
		} 
		
		bool compare_colors(SDL_Color c1, SDL_Color c2)
		{
			return c1.r==c2.r && c1.g==c2.g && c1.b==c2.b;
		}		
};

#endif
