/*   This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; version 2 of the License.
   
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
     
     (C) 2006 schan
*/
#include "text.h"
#include <string>
#include <fstream>
#include <iostream>


TextRenderer::~TextRenderer()
{
}


Text::Text()
{
	renderer = NULL;
	width = 0;
	height = 0;
}
		
Text::~Text()
{
	if (renderer==NULL) delete renderer;
}
		
void Text::set_renderer(TextRenderer *r)
{
	if (renderer==NULL) delete renderer;
	renderer = r;
}
		
void Text::set_file(const std::string &filename, int encoding)
{
	this->filename = filename;
	this->encoding = encoding;
}

void Text::load()
{
	renderer->reset();
	std::ifstream file(filename.c_str());
	std::string currentLine;

	while (!file.eof() )
	{
		std::getline(file,currentLine);
		renderer->add_line(currentLine,encoding);
	}
	file.close();		 
}
		
void Text::render(SDL_Surface *dest)
{
	renderer->render(dest);
}
		
void Text::next_page()
{
	renderer->next_page();
}

void Text::prev_page()
{
	renderer->prev_page();
} 

void Text::next_line()
{
	renderer->next_line();
}

void Text::prev_line()
{
	renderer->prev_line();
} 

void Text::go_to_line(unsigned long int n)
{
	renderer->go_to_line(n);
} 


void Text::set_font(BitmapFont *f)
{
	font = f;
	if (renderer!=NULL) renderer->set_font(f);
}

void Text::set_viewport_width(int w)
{
	width = w;
	if (renderer!=NULL) renderer->set_viewport_width(w);
}

void Text::set_viewport_height(int h)
{
	height = h;
	if (renderer!=NULL) renderer->set_viewport_height(h);
}

void Text::reload()
{
	if (filename!="" && renderer!=NULL)
	{
		load();
	}
}
